@@ -7,7 +7,8 @@ use thiserror::Error;
 pub enum GitMitError {
     #[error("failed to convert author command output to unicode")]
     #[diagnostic(
-        code(git_mit::config::author::load),
+        url(docsrs),
+        code(git_mit::errors::git_mit_error::exec_utf8),
         help("all characters must parse as utf8")
     )]
     ExecUtf8 {
@@ -17,10 +18,16 @@ pub enum GitMitError {
         source: FromUtf8Error,
     },
     #[error("no mit initials provided")]
+    #[diagnostic(
+        url(docsrs),
+        code(git_mit::errors::git_mit_error::no_author_initials_provided)
+    )]
     NoAuthorInitialsProvided,
     #[error("no timeout set")]
+    #[diagnostic(url(docsrs), code(git_mit::errors::git_mit_error::no_timeout_set))]
     NoTimeoutSet,
     #[error("expected a mit file path, didn't find one")]
+    #[diagnostic(url(docsrs), code(git_mit::errors::git_mit_error::author_file_not_set))]
     AuthorFileNotSet,
 }
 
